@@ -11,11 +11,11 @@ import os
 # Setup configuration: will be parsed by setup.py -------------------
 # Values must be in one line
 # Project version.
-VERSION='2.2.1'
+VERSION='2.2.3'
 # URL that will be displayed in help and other places
 GIT_URL="https://github.com/tristanlatr/WPWatcher"
 # Authors
-AUTHORS="Florian Roth, Tristan Landès"
+AUTHORS="Florian Roth, Tristan Landes"
 
 # Global variables ------------------
 # Global log handler
