@@ -15,7 +15,7 @@ import multiprocessing.pool
 from datetime import timedelta, datetime
 from wpwatcher import log
 from wpwatcher.utils import get_valid_filename, safe_log_wpscan_args, oneline, timeout
-from wpwatcher.parser import parse_results
+from wpwatcher.parser import parse_results, is_false_positive
 from wpwatcher.notification import WPWatcherNotification
 from wpwatcher.wpscan import WPScanWrapper
 from wpwatcher.config import WPWatcherConfig
@@ -32,7 +32,6 @@ DATE_FORMAT='%Y-%m-%dT%H-%M-%S'
 class WPWatcherScanner():
     
     def __init__(self, conf):
-        # self.conf=conf
 
         # Create (lazy) wpscan link
         self.wpscan=WPScanWrapper(conf['wpscan_path'])
@@ -57,6 +56,9 @@ class WPWatcherScanner():
         self.daemon_loop_sleep=conf['daemon_loop_sleep']
         self.prescan_without_api_token=conf['prescan_without_api_token']
 
+        # Scan timeout
+        self.scan_timeout=conf['scan_timeout']
+
         # Setup prescan options
         self.prescanned_sites_warn=[]
         self.api_token=None
@@ -91,7 +93,7 @@ class WPWatcherScanner():
         env=['HOME', 'XDG_CONFIG_HOME', 'APPDATA', 'PWD']
         for wpscan_config_file in WPWatcherConfig.find_files(env, files):
             with open(wpscan_config_file,'r') as wpscancfg:
-                if any ([ 'api_token' in line and line.strip[0] is not "#" for line in wpscancfg.readlines() ]):
+                if any ([ 'api_token' in line and line.strip()[0] != "#" for line in wpscancfg.readlines() ]):
                     log.error('API token is set in the config file %s, please remove it to allow WPWatcher to handle WPScan API token'%(wpscan_config_file))
                     return False
         return True
@@ -105,22 +107,24 @@ class WPWatcherScanner():
         token = wpscan_args[api_token_index]
         return token
 
-    @staticmethod
-    def get_fixed_issues(wp_report, last_wp_report, issue_type='alerts'):
+    def get_fixed_issues(self, wp_report, last_wp_report, wp_site, issue_type='alerts'):
+        """Return list of fixed issue texts to include in mails"""
         issues=[]
-        for last_alert in last_wp_report[issue_type]:
-            if last_alert.splitlines()[0] not in [ a.splitlines()[0] for a in wp_report[issue_type] ]:
-                issues.append('%s regarding component "%s" has been fixed since last report.\nLast report sent the %s.\nFix detected the %s\nIssue details:\n%s'%('Alert' if issue_type=='alerts' else 'Issue', 
-                    last_alert.splitlines()[0], last_wp_report['last_email'], wp_report['datetime'], last_alert))
+        for last_alert in last_wp_report[issue_type] :
+            if not is_false_positive(last_alert, self.false_positive_strings+wp_site['false_positive_strings']) :
+                if last_alert.splitlines()[0] not in [ a.splitlines()[0] for a in wp_report[issue_type] ]:
+                    issues.append('%s regarding component "%s" has been fixed since last report.\nLast report sent the %s'%(
+                        'Alert' if issue_type=='alerts' else 'Issue', 
+                        last_alert.splitlines()[0], last_wp_report['last_email']) )
         return issues
 
-    def update_report(self, wp_report, last_wp_report):
+    def update_report(self, wp_report, last_wp_report, wp_site):
         if last_wp_report:
             # Fill out fixed issues and last_email datetime
             # Save already fixed issues but not reported yet
             wp_report['fixed']=last_wp_report['fixed']
-            wp_report['fixed'].extend( self.get_fixed_issues(wp_report, last_wp_report, 'alerts') )
-            if self.mail.send_warnings : wp_report['fixed'].extend( self.get_fixed_issues(wp_report, last_wp_report, 'warnings') )
+            wp_report['fixed'].extend( self.get_fixed_issues(wp_report, last_wp_report, wp_site, issue_type='alerts') )
+            if self.mail.send_warnings : wp_report['fixed'].extend( self.get_fixed_issues(wp_report, last_wp_report, wp_site, issue_type='warnings') )
 
             # Save last email datetime if any
             if last_wp_report['last_email']:
@@ -192,8 +196,6 @@ class WPWatcherScanner():
             if ( wp_site['url'] in p.args ) and not p.returncode:
                 log.info('Killing WPScan process %s'%(safe_log_wpscan_args(p.args)))
                 p.kill()
-        # Discard wpscan_output from report
-        if 'wpscan_output' in wp_report: del wp_report['wpscan_output']
 
     # Scan process
 
@@ -202,15 +204,20 @@ class WPWatcherScanner():
         self.wpscan.init_check_done=False # will re-trigger wpscan update next time wpscan() is called 
         self.api_wait.wait(API_WAIT_SLEEP.total_seconds())
         if self.interrupting: return ((None, True))
-        return ((self.wpscan_site(wp_site, wp_report), True))
+
+        new_report=self.scan_site(wp_site)
+        return ((new_report, new_report != None))
 
     def handle_wpscan_err_follow_redirect(self,wp_site, wp_report):
         url = re.findall(r'http[s]?://(?:[a-zA-Z]|[0-9]|[$-_@.&+]|[!*\(\),]|(?:%[0-9a-fA-F][0-9a-fA-F]))+',
             wp_report["wpscan_output"].split("The URL supplied redirects to")[1] )
+
         if len(url)==1:
             wp_site['url']=url[0].strip()
             log.info("Following redirection to %s"%wp_site['url'])
-            return ((self.wpscan_site(wp_site, wp_report), True))
+            new_report=self.scan_site(wp_site)
+            return ((new_report, new_report != None))
+
         else:
             err_str="Could not parse the URL to follow in WPScan output after words 'The URL supplied redirects to'"
             log.error(err_str)
@@ -255,7 +262,8 @@ class WPWatcherScanner():
         # Handle scan errors -----
         
         # Quick return if interrupting and/or if user cacelled scans
-        if self.interrupting or wpscan_exit_code in [2, -2, -9] : return None
+        if self.interrupting or wpscan_exit_code in [2, -2, -9] : 
+            return None
         
         # Other errors codes : -9, -2, 127, etc:
         # or wpscan_exit_code not in [1,3,4]
@@ -267,30 +275,62 @@ class WPWatcherScanner():
     def wpscan_site(self, wp_site, wp_report):
         # Launch WPScan
         try:
-            wp_report_new=self._wpscan_site(wp_site, wp_report)
+            wp_report_new= timeout(self.scan_timeout.total_seconds(), self._wpscan_site, args=(wp_site, wp_report) )
             if wp_report_new: wp_report.update(wp_report_new)
             else : return None
-        except RuntimeError as err:
-             # Try to handle error and return, Reccursive call to wpscan_site
-            wp_report_new, handled = self.handle_wpscan_err(wp_site, wp_report)
-            if handled and wp_report_new: wp_report.update(wp_report_new)
-            if handled: return wp_report
-            else: 
-                log.error("Could not scan site %s"%wp_site['url'])
-                wp_report['errors'].append(str(err))
-                # Fail fast
-                self.check_fail_fast()
+        except TimeoutError:
+            wp_report['errors'].append("Timeout scanning site after %s seconds.\nSetup scan_timeout in config file to allow more time"%self.scan_timeout.total_seconds())
+            log.error("Timeout scanning site %s after %s seconds. Setup scan_timeout in config file to allow more time"%(wp_site['url'], self.scan_timeout.total_seconds()))
+            # Terminate
+            self.terminate_scan(wp_site, wp_report)
+            self.check_fail_fast()
+
         return wp_report
 
     # Orchestrate the scanning of a site
-    def _scan_site(self, wp_site, wp_report, last_wp_report=None):
+    def scan_site(self, wp_site, last_wp_report=None):
+
+        # Init report variables
+        wp_report={
+            "site":wp_site['url'],
+            "status":None,
+            "datetime": datetime.now().strftime(DATE_FORMAT),
+            "last_email":None,
+            "errors":[],
+            "infos":[],
+            "warnings":[],
+            "alerts":[],
+            "fixed":[],
+            "wpscan_output":"" # will be deleted
+        }
 
         # Skip if the daemon mode is enabled and scan already happend in the last configured `daemon_loop_wait`
-        if last_wp_report and self.skip_this_site(wp_report, last_wp_report): return None
+        if last_wp_report and self.skip_this_site(wp_report, last_wp_report): 
+            return None
         
         # Launch WPScan
-        # Abnormal failure exit codes not in 0-5 and not while tearing down program
-        if not self.wpscan_site(wp_site, wp_report): return None
+        try:
+            # Abnormal failure exit codes not in 0-5
+            if not self.wpscan_site(wp_site, wp_report): 
+                log.error("Abnormal failure scanning %s exit code not 0 or 5"%(wp_site['url']))
+                return None
+
+        except RuntimeError as err:
+            # Try to handle error and return, recall scan_site()
+            wp_report_new, handled = self.handle_wpscan_err(wp_site, wp_report)                
+            if handled:
+                wp_report=wp_report_new
+                return wp_report
+
+            elif not self.interrupting: 
+                log.error("Could not scan site %s"%wp_site['url'])
+                log.debug(traceback.format_exc())
+                wp_report['errors'].append(str(err))
+                # Fail fast
+                self.check_fail_fast()
+
+            else:
+                return None
 
         self.fill_report_status(wp_report)
 
@@ -307,11 +347,16 @@ class WPWatcherScanner():
         if wpscan_results_file: log.info("WPScan output saved to file %s"%wpscan_results_file)
         
         # Updating report entry with data from last scan 
-        self.update_report(wp_report, last_wp_report)
+        self.update_report(wp_report, last_wp_report, wp_site)
 
         # Notify recepients if match triggers
         try:
-            self.mail.notify(wp_site, wp_report, last_wp_report)
+            if self.mail.notify(wp_site, wp_report, last_wp_report):
+                # Store report time
+                wp_report['last_email']=datetime.now().strftime(DATE_FORMAT)
+                # Discard fixed items because infos have been sent
+                wp_report['fixed']=[]
+
         except RuntimeError: 
             # Fail fast
             self.check_fail_fast()
@@ -319,35 +364,10 @@ class WPWatcherScanner():
         # Save scanned site
         self.scanned_sites.append(wp_site['url'])
 
+        # Discard wpscan_output from report
+        if 'wpscan_output' in wp_report: 
+            del wp_report['wpscan_output']
+
         self.terminate_scan(wp_site, wp_report)
 
-        return(wp_report)
-
-        # timeout wrapper
-    def scan_site(self, wp_site, last_wp_report=None, timeout_seconds=300):
-        
-        # Init report variables
-        wp_report={
-            "site":wp_site['url'],
-            "status":None,
-            "datetime": datetime.now().strftime(DATE_FORMAT),
-            "last_email":None,
-            "errors":[],
-            "infos":[],
-            "warnings":[],
-            "alerts":[],
-            "fixed":[],
-            "wpscan_output":"" # will be deleted
-        }
-
-        # Wait until process finishes
-        try: wp_report = timeout(timeout_seconds, self._scan_site, args=(wp_site, wp_report, last_wp_report))
-        except TimeoutError:
-            wp_report['status']='ERROR'
-            wp_report['errors'].append("Timeout scanning site after %s seconds"%timeout_seconds)
-            log.error("Timeout scanning site %s after %s seconds."%(wp_site['url'], timeout_seconds))
-            # Terminate
-            self.terminate_scan(wp_site, wp_report)
-            self.check_fail_fast()
-
-        return wp_report
+        return(wp_report)
\ No newline at end of file
